==> mgb-0.6.9.3.tar.bz2: language/lang_turkish_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ========================================= //
	// lang_main.php - Turkish by Mustafa Dündar //
	// ========================================= //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// INDEX.PHP
	$lang['install_directory_exists'] = "Kurulum dizini silinmedi.<br>Keni güvenliðin için þimdi yap!<br>Güncelleþtirmeden sonra çalýþtýrmayý <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> unutma!";
	$lang['new_entry'] = "Kayýt";
	$lang['new_entry_descr'] = "Burada bir Ziyaretci Defterine yazabilirsin";
	$lang['contact'] = "Ýletiþim";
	$lang['contact_descr'] = "Sen burada Yönetici ile iliþgiye girebilirsin";
	$lang['adminpanel'] = "Yönetim";
	$lang['adminpanel_descr'] = "Oturum açmak için";
	$lang['entry'] = "Giriþ";
	$lang['entries'] = "Giriþler";
	$lang['no_entries'] = "Malesef hiç bir <br>giriþ yapýlmamýþtýr.";
	$lang['entries_on_pages'] = "Giriþler {PAGES} Sayfa";
	$lang['page_first'] = "Ýlk sayfaya ";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Bir Sayfa ileri git";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Son Sayfa";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Bir sayfa geri git";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor']	= "Bu giriþe doðrudan git";
	$lang['from'] = "dan";
	$lang['at'] = "için";
	$lang['oclock']	= "Saat";
	$lang['comment'] = "Yorum";
	$lang['email_yes'] = "eMail {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} Ziyaretçi Defterinden e-Posta almak istemiyorsanýz.";
	$lang['hp_of'] = "Anasayfa {ENTRY_NAME}";
	$lang['gravatar'] = "Gravator {ENTRY_NAME}";
	$lang['quote'] = "Quote of";

	// NEWENTRY.PHP
	$lang['name'] = "Adýn:";
	$lang['city'] = "Oturduðun yer:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Ýnternet Sitesi:";
	$lang['message'] = "Senin Mesajýn:";
	$lang['necessary_fields'] = "[ (*) iþaretli yerleri doldurmanýz gerekir ]";
	$lang['user_notification'] = "Eðer bir giriþ veya Mesaj yazýldýðýnda e-Posta ile haber verilir.";
	$lang['user_show_email'] = "Ýletiþim Formu aracýlýðý ile bana diger kullanýcýlardan e-Posta yazmasý için izin ver. Spam önlemek için benim e-Posta adresimi gösterme.";
	$lang['user_accept_akismet_service'] = "This entry will be checked by the plugin 'Akismet' on spam. I am aware of the circumstance, that personal data of me will be sent to a server in the United States of America and i do accept this.";
	$lang['send'] = "Kayýt";
	$lang['preview'] = "Önizleme";
	$lang['security_code'] = "Güvenlik Kodu";
	$lang['captcha_what_is_that'] = "Bu nedir?";
	$lang['captcha_wikipedia'] = "http://de.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "Yeni bir giriþ otomatik kayýtlarý engellemek için bir güvenlik kodu gerektirir. Lütfen bütün harfleri büyük gir. Eðer Kod okunamzise boþ yaz ''Eintragen''. Yeni bir Kod oluþturulur. Önceki verdiðin deðerler kalýr. Eðer yeni Cod oluþmazise saðtarafta ''Aktualisieren'' bas.";
	$lang['back_to_mainpage'] = "Ana Sayfaya geri dön";
	$lang['back'] = "Geri";
	$lang['entry_success_mod'] = "Yorum baþarýyla kaydedildi. <br>O, Yönetici tarafýndan incelenir, sonra yayýnlanýr.";
	$lang['entry_success'] = "Yorum baþarýyla kaydedildi. Bunu hemen görebilirsiniz.";
	$lang['forwarding'] = "5 saniye içinde otamatik olarak yönlendirileceksiniz. Deðilse Anasayfaya ''Geri'' bas.";

	// EMAIL.PHP
	$lang['email_name'] = "Senin Ýsmin:";
	$lang['email_email'] = "Senin eMail:";
	$lang['email_message'] = "Senin Haberin:";
	$lang['email_sent_to'] = "Bu eMail ona gönderilecektir:";
	$lang['email_send'] = "gönder";
	$lang['email_caption'] = "e-Posta '{NAME}' Ziyaretçi Defteri üzerine {DOMAIN} den";
	$lang['email_sender'] = "Gönderen:";
	$lang['email_receiver'] = "Alýcý:";
	$lang['email_from'] = "üzerinde:";
	$lang['email_sendcopytome'] = "Bu e-Postanin bir kopyasýný istiyorum.";
	$lang['email_success'] = "Senin e-Postan kullanýcýya baþarýyla gönderilmiþtir.";
	$lang['email_fail'] = "E-Posta gönderilemedi. Posta sunucusu ile ilgili bir sorun olabilir.";

	// ERRORMESSAGES
	$lang['errormessage1'] = "Bir mesaj girin!";
	$lang['errormessage2'] = "Geçerli bir eMail adresi girin!";
	$lang['errormessage3'] = "Lütfen isminizi giriniz!";
	$lang['errormessage4'] = "geçerli bir <br>eMail adresi deðil!";
	$lang['errormessage5'] = "geçerli býr <br>ICQ numarasý deðil!";
	$lang['errormessage6'] = "IP Blogu bir daha giriþe yasaklý!";
	$lang['errormessage7'] = "Güvenlik kodu yanlýþ veya girilmedi!";
	$lang['errormessage8'] = "Bu Kullanýcý e-Posta almak istemiyor!";
	$lang['errormessage9'] = "E-Posta giderken bir hata oluþtu!";
	$lang['errormessage10'] = "Spam-protection: The entry form was sent too fast. Please wait {TIME_LOCK_REST} more seconds. Thank you.";
	$lang['errormessage11'] = "The Akismet data privacy agreement was not accepted. It MUST be accepted to save the entry.";

	// BBCODES
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_bold'] = "Yað";
	$lang['bbcode_help_bold'] = "Displays text bold";
	$lang['bbcode_italic'] = "Ýtalik";
	$lang['bbcode_help_italic'] = "Displays text italic";
	$lang['bbcode_url'] = "Baðlantý";
	$lang['bbcode_help_url'] = "Inserts a hyperlink. Possibilities: [url]http://www.test.tr/[/url] or [url=http://www.test.tr/]Test[/url] or [url=http://www.test.tr/][img]url of image[/img][/url]";
	$lang['bbcode_img'] = "Image";
	$lang['bbcode_help_img'] = "Inserts an image. Possibilities: [img]url of image[/img] or [img=width,height]url of image[/img]";
	$lang['bbcode_flash'] = "Flash";
	$lang['bbcode_help_flash'] = "Inserts a flash video. Possibilities: [flash=width,height]url of video[/flash]";
	$lang['bbcode_quote'] = "Quote";
	$lang['bbcode_help_quote'] = "Inserts a quote. Possibilites: [quote]QUOTE[/quote] or [quote=Name]QUOTE[/quote]";
	$lang['bbcode_textsize'] = "Yazý tipi boyutu";
	$lang['bbcode_extrasmall'] = "Minik";
	$lang['bbcode_small'] = "Küçük";
	$lang['bbcode_default'] = "Standart";
	$lang['bbcode_big'] = "Birleþik";
	$lang['bbcode_extrabig'] = "Kocaman";
	$lang['bbcode_textcolor'] = "Yazý tipi rengi";
	$lang['bbcode_help_size'] = "Yayý tipi boyutu";
	$lang['smileys'] = "Smilies:";

	$lang['sendmail_admin_title'] = "Yeni giriþ '{NAME}'";
	$lang['sendmail_user_title'] = "Kayýt {DOMAIN}";
?>

==> mgb-0.6.9.5.tar.bz2: language/lang_turkish_utf8/lang_main.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =======================
	// lang_main.php - Turkish
	// =======================

	// Translated by Mustafa Dündar
	// ++++++++++++++++++++++++++++

	// INDEX.PHP
	$lang['install_directory_exists'] = "Kurulum dizini silinmedi.<br>Keni güvenliðin için þimdi yap!<br>Güncelleþtirmeden sonra çalýþtýrmayý <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> unutma!";
	$lang['new_entry'] = "Kayýt";
	$lang['new_entry_descr'] = "Burada bir Ziyaretci Defterine yazabilirsin";
	$lang['contact'] = "Ýletiþim";
	$lang['contact_descr'] = "Sen burada Yönetici ile iliþgiye girebilirsin";
	$lang['adminpanel'] = "Yönetim";
	$lang['adminpanel_descr'] = "Oturum açmak için";
	$lang['entry'] = "Giriþ";
	$lang['entries'] = "Giriþler";
	$lang['no_entries'] = "Malesef hiç bir <br>giriþ yapýlmamýþtýr.";
	$lang['entries_on_pages'] = "Giriþler {PAGES} Sayfa";
	$lang['page_first'] = "Ýlk sayfaya ";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "Bir Sayfa ileri git";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Son Sayfa";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "Bir sayfa geri git";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['anchor']	= "Bu giriþe doðrudan git";
	$lang['from'] = "dan";
	$lang['at'] = "için";
	$lang['oclock']	= "Saat";
	$lang['comment'] = "Yorum";
	$lang['email_yes'] = "eMail {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} Ziyaretçi Defterinden e-Posta almak istemiyorsanýz.";
	$lang['hp_of'] = "Anasayfa {ENTRY_NAME}";
	$lang['gravatar'] = "Gravator {ENTRY_NAME}";
	$lang['quote'] = "Quote of";

	// NEWENTRY.PHP
	$lang['name'] = "Adýn:";
	$lang['city'] = "Oturduðun yer:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Ýnternet Sitesi:";
	$lang['message'] = "Senin Mesajýn:";
	$lang['necessary_fields'] = "[ (*) iþaretli yerleri doldurmanýz gerekir ]";
	$lang['user_notification'] = "Eðer bir giriþ veya Mesaj yazýldýðýnda e-Posta ile haber verilir.";
	$lang['user_show_email'] = "Ýletiþim Formu aracýlýðý ile bana diger kullanýcýlardan e-Posta yazmasý için izin ver. Spam önlemek için benim e-Posta adresimi gösterme.";
	$lang['user_accept_akismet_service'] = "This entry will be checked by the plugin 'Akismet' on spam. I am aware of the circumstance, that personal data of me will be sent to a server in the United States of America and i do accept this.";
	$lang['send'] = "Kayýt";
	$lang['preview'] = "Önizleme";
	$lang['security_code'] = "Güvenlik Kodu";
	$lang['captcha_refresh'] = "Generate new captcha code";
	$lang['captcha_what_is_that'] = "Bu nedir?";
	$lang['captcha_wikipedia'] = "http://tr.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "Yeni bir giriþ otomatik kayýtlarý engellemek için bir güvenlik kodu gerektirir. Lütfen bütün harfleri büyük gir. Eðer Kod okunamzise boþ yaz ''Eintragen''. Yeni bir Kod oluþturulur. Önceki verdiðin deðerler kalýr. Eðer yeni Cod oluþmazise saðtarafta ''Aktualisieren'' bas.";
	$lang['back_to_mainpage'] = "Ana Sayfaya geri dön";
	$lang['back'] = "Geri";
	$lang['entry_success_mod'] = "Yorum baþarýyla kaydedildi. <br>O, Yönetici tarafýndan incelenir, sonra yayýnlanýr.";
	$lang['entry_success'] = "Yorum baþarýyla kaydedildi. Bunu hemen görebilirsiniz.";
	$lang['forwarding'] = "5 saniye içinde otamatik olarak yönlendirileceksiniz. Deðilse Anasayfaya ''Geri'' bas.";

	// EMAIL.PHP
	$lang['email_name'] = "Senin Ýsmin:";
	$lang['email_email'] = "Senin eMail:";
	$lang['email_message'] = "Senin Haberin:";
	$lang['email_sent_to'] = "Bu eMail ona gönderilecektir:";
	$lang['email_send'] = "gönder";
	$lang['email_caption'] = "e-Posta '{NAME}' Ziyaretçi Defteri üzerine {DOMAIN} den";
	$lang['email_caption_copy'] = "Email to '{NAME}' through the guestbook of {DOMAIN} - Copy";
	$lang['email_sender'] = "Gönderen:";
	$lang['email_receiver'] = "Alýcý:";
	$lang['email_from'] = "üzerinde:";
	$lang['email_sendcopytome'] = "Bu e-Postanin bir kopyasýný istiyorum.";
	$lang['email_success'] = "Senin e-Postan kullanýcýya baþarýyla gönderilmiþtir.";
	$lang['email_fail'] = "E-Posta gönderilemedi. Posta sunucusu ile ilgili bir sorun olabilir.";

	// ERRORMESSAGES
	$lang['errormessage1'] = "Bir mesaj girin!";
	$lang['errormessage2'] = "Geçerli bir eMail adresi girin!";
	$lang['errormessage3'] = "Lütfen isminizi giriniz!";
	$lang['errormessage4'] = "geçerli bir <br>eMail adresi deðil!";
	$lang['errormessage5'] = "geçerli býr <br>ICQ numarasý deðil!";
	$lang['errormessage6'] = "IP Blogu bir daha giriþe yasaklý!";
	$lang['errormessage7'] = "Güvenlik kodu yanlýþ veya girilmedi!";
	$lang['errormessage8'] = "Bu Kullanýcý e-Posta almak istemiyor!";
	$lang['errormessage9'] = "E-Posta giderken bir hata oluþtu!";
	$lang['errormessage10'] = "Spam-protection: The entry form was sent too fast. Please wait {TIME_LOCK_REST} more seconds. Thank you.";
	$lang['errormessage11'] = "The Akismet data privacy agreement was not accepted. It MUST be accepted to save the entry.";

	// BBCODES
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_bold'] = "Yað";
	$lang['bbcode_help_bold'] = "Displays text bold";
	$lang['bbcode_italic'] = "Ýtalik";
	$lang['bbcode_help_italic'] = "Displays text italic";
	$lang['bbcode_url'] = "Baðlantý";
	$lang['bbcode_help_url'] = "Inserts a hyperlink. Possibilities: [url]http://www.test.tr/[/url] or [url=http://www.test.tr/]Test[/url] or [url=http://www.test.tr/][img]url of image[/img][/url]";
	$lang['bbcode_img'] = "Image";
	$lang['bbcode_help_img'] = "Inserts an image. Possibilities: [img]url of image[/img] or [img=width,height]url of image[/img]";
	$lang['bbcode_flash'] = "Flash";
	$lang['bbcode_help_flash'] = "Inserts a flash video. Possibilities: [flash=width,height]url of video[/flash]";
	$lang['bbcode_quote'] = "Quote";
	$lang['bbcode_help_quote'] = "Inserts a quote. Possibilites: [quote]QUOTE[/quote] or [quote=Name]QUOTE[/quote]";
	$lang['bbcode_textsize'] = "Yazý tipi boyutu";
	$lang['bbcode_extrasmall'] = "Minik";
	$lang['bbcode_small'] = "Küçük";
	$lang['bbcode_default'] = "Standart";
	$lang['bbcode_big'] = "Birleþik";
	$lang['bbcode_extrabig'] = "Kocaman";
	$lang['bbcode_textcolor'] = "Yazý tipi rengi";
	$lang['bbcode_help_size'] = "Yayý tipi boyutu";
	$lang['smileys'] = "Smilies:";

	$lang['sendmail_admin_title'] = "Yeni giriþ '{NAME}'";
	$lang['sendmail_user_title'] = "Kayýt {DOMAIN}";
?>
